@@ -24,7 +24,7 @@ Testing:
     xdoctest ubelt
 """
 
-__version__ = '1.1.2'
+__version__ = '1.2.0'
 
 __submodules__ = {
     'util_arg': None,
@@ -91,11 +91,12 @@ from ubelt.util_cache import (CacheStamp, Cacher,)
 from ubelt.util_colors import (NO_COLOR, color_text, highlight_code,)
 from ubelt.util_const import (NoParam,)
 from ubelt.util_cmd import (cmd,)
-from ubelt.util_dict import (AutoDict, AutoOrderedDict, ddict, dict_diff,
-                             dict_hist, dict_isect, dict_subset, dict_union,
-                             dzip, find_duplicates, group_items, invert_dict,
-                             map_keys, map_vals, named_product, odict,
-                             sorted_keys, sorted_vals, varied_values,)
+from ubelt.util_dict import (AutoDict, AutoOrderedDict, SetDict, UDict, ddict,
+                             dict_diff, dict_hist, dict_isect, dict_subset,
+                             dict_union, dzip, find_duplicates, group_items,
+                             invert_dict, map_keys, map_vals, map_values,
+                             named_product, odict, sdict, sorted_keys,
+                             sorted_vals, sorted_values, udict, varied_values,)
 from ubelt.util_deprecate import (schedule_deprecation,)
 from ubelt.util_download import (download, grabdata,)
 from ubelt.util_download_manager import (DownloadManager,)
@@ -134,27 +135,28 @@ __all__ = ['AutoDict', 'AutoOrderedDict', 'CacheStamp', 'Cacher',
            'CaptureStdout', 'CaptureStream', 'DARWIN', 'DownloadManager',
            'Executor', 'FormatterExtensions', 'IndexableWalker', 'JobPool',
            'LINUX', 'NO_COLOR', 'NiceRepr', 'NoParam', 'OrderedSet', 'POSIX',
-           'Path', 'ProgIter', 'TeeStringIO', 'TempDir', 'Timer', 'WIN32',
-           'allsame', 'argflag', 'argmax', 'argmin', 'argsort', 'argunique',
-           'argval', 'augpath', 'boolmask', 'chunks', 'cmd', 'codeblock',
-           'color_text', 'compatible', 'compress', 'ddict', 'delete',
-           'dict_diff', 'dict_hist', 'dict_isect', 'dict_subset', 'dict_union',
-           'download', 'dzip', 'ensure_app_cache_dir', 'ensure_app_config_dir',
-           'ensure_app_data_dir', 'ensure_unicode', 'ensuredir', 'expandpath',
-           'find_duplicates', 'find_exe', 'find_path', 'flatten',
-           'get_app_cache_dir', 'get_app_config_dir', 'get_app_data_dir',
-           'grabdata', 'group_items', 'hash_data', 'hash_file',
-           'highlight_code', 'hzcat', 'identity', 'import_module_from_name',
-           'import_module_from_path', 'indent', 'indexable_allclose',
-           'inject_method', 'invert_dict', 'iter_window', 'iterable',
-           'map_keys', 'map_vals', 'memoize', 'memoize_method',
-           'memoize_property', 'modname_to_modpath', 'modpath_to_modname',
-           'named_product', 'odict', 'orderedset', 'oset', 'paragraph', 'peek',
-           'platform_cache_dir', 'platform_config_dir', 'platform_data_dir',
-           'progiter', 'readfrom', 'repr2', 'schedule_deprecation',
-           'shrinkuser', 'sorted_keys', 'sorted_vals', 'split_archive',
+           'Path', 'ProgIter', 'SetDict', 'TeeStringIO', 'TempDir', 'Timer',
+           'UDict', 'WIN32', 'allsame', 'argflag', 'argmax', 'argmin',
+           'argsort', 'argunique', 'argval', 'augpath', 'boolmask', 'chunks',
+           'cmd', 'codeblock', 'color_text', 'compatible', 'compress', 'ddict',
+           'delete', 'dict_diff', 'dict_hist', 'dict_isect', 'dict_subset',
+           'dict_union', 'download', 'dzip', 'ensure_app_cache_dir',
+           'ensure_app_config_dir', 'ensure_app_data_dir', 'ensure_unicode',
+           'ensuredir', 'expandpath', 'find_duplicates', 'find_exe',
+           'find_path', 'flatten', 'get_app_cache_dir', 'get_app_config_dir',
+           'get_app_data_dir', 'grabdata', 'group_items', 'hash_data',
+           'hash_file', 'highlight_code', 'hzcat', 'identity',
+           'import_module_from_name', 'import_module_from_path', 'indent',
+           'indexable_allclose', 'inject_method', 'invert_dict', 'iter_window',
+           'iterable', 'map_keys', 'map_vals', 'map_values', 'memoize',
+           'memoize_method', 'memoize_property', 'modname_to_modpath',
+           'modpath_to_modname', 'named_product', 'odict', 'orderedset',
+           'oset', 'paragraph', 'peek', 'platform_cache_dir',
+           'platform_config_dir', 'platform_data_dir', 'progiter', 'readfrom',
+           'repr2', 'schedule_deprecation', 'sdict', 'shrinkuser',
+           'sorted_keys', 'sorted_vals', 'sorted_values', 'split_archive',
            'split_modpath', 'symlink', 'take', 'timeparse', 'timestamp',
-           'touch', 'unique', 'unique_flags', 'userhome', 'util_arg',
+           'touch', 'udict', 'unique', 'unique_flags', 'userhome', 'util_arg',
            'util_cache', 'util_cmd', 'util_colors', 'util_const',
            'util_deprecate', 'util_dict', 'util_download',
            'util_download_manager', 'util_format', 'util_func', 'util_futures',
