@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 For dealing with symlinks, junctions, and hard-links on windows.
 
@@ -15,14 +14,12 @@ Weird Behavior:
     - [ ] In many cases using the win32 API seems to result in privilege errors
           but using shell commands does not have this problem.
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 import warnings
 from os.path import exists
 from os.path import join
 from ubelt import util_io
 from ubelt import util_path
-from ubelt.util_path import _fspath
 import sys
 
 if sys.platform.startswith('win32'):
@@ -50,8 +47,12 @@ def _win32_can_symlink(verbose=0, force=0, testing=0):
     if __win32_can_symlink__ is not None and not force:
         return __win32_can_symlink__
 
-    from ubelt import util_platform
-    tempdir = util_platform.ensure_app_cache_dir('ubelt', '_win32_can_symlink')
+    # We have to use a unique directory otherwise we encounter multiprocess
+    # race conditions.
+    import tempfile
+    tempdir = tempfile.mkdtemp(suffix='_win32_can_symlink')
+    # from ubelt import util_platform
+    # tempdir = util_platform.ensure_app_cache_dir('ubelt', '_win32_can_symlink')
 
     try:
         util_io.delete(tempdir)
@@ -250,7 +251,7 @@ def _win32_symlink(path, link, verbose=0):
         info = util_cmd.cmd(command, shell=True)
         if info['ret'] != 0:
             from ubelt import util_format
-            permission_msg = 'You do not have sufficient privledges'
+            permission_msg = 'You do not have sufficient privledge'
             if permission_msg not in info['err']:
                 print('Failed command:')
                 print(info['command'])
@@ -403,35 +404,6 @@ def _win32_read_junction(path):
     return subname
 
 
-def _fspath(path):
-    """
-    For cases where os.fspath does not exist on older Python
-    """
-    import six
-    string_types = six.string_types
-
-    if isinstance(path, string_types):
-        return path
-
-    # Work from the object's type to match method resolution of other magic
-    # methods.
-    path_type = type(path)
-    try:
-        path_repr = path_type.__fspath__(path)
-    except AttributeError:
-        if hasattr(path_type, '__fspath__'):
-            raise
-        else:
-            raise TypeError("expected str, bytes or os.PathLike object, "
-                            "not " + path_type.__name__)
-    if isinstance(path_repr, string_types):
-        return path_repr
-    else:
-        raise TypeError("expected {}.__fspath__() to return str or bytes, "
-                        "not {}".format(path_type.__name__,
-                                        type(path_repr).__name__))
-
-
 def _win32_rmtree(path, verbose=0):
     """
     rmtree for win32 that treats junctions like directory symlinks.
@@ -443,7 +415,7 @@ def _win32_rmtree(path, verbose=0):
     References:
         .. [CPythonBug31226] https://bugs.python.org/issue31226
     """
-    path = _fspath(path)
+    path = os.fspath(path)
 
     def _rmjunctions(root):
         from os.path import join, isdir, islink
