@@ -110,6 +110,10 @@ Example:
     >>> # modifying or removing the file will cause the stamp to expire
     >>> expected_fpaths[0].write_text('corrupted')
     >>> assert self.expired()
+
+
+RelatedWork:
+    https://github.com/shaypal5/cachier
 """
 import os
 from os.path import join, normpath, basename, exists
@@ -373,25 +377,26 @@ class Cacher(object):
             str: paths to cached files corresponding to this cacher
 
         Example:
-            >>> from ubelt.util_cache import Cacher
             >>> # Ensure that some data exists
-            >>> known_fpaths = set()
             >>> import ubelt as ub
-            >>> dpath = ub.ensure_app_cache_dir('ubelt',
-            >>>                                 'test-existing-versions')
-            >>> ub.delete(dpath)  # start fresh
-            >>> cacher = Cacher('versioned_data_v2', depends='1', dpath=dpath)
+            >>> dpath = ub.Path.appdir(
+            >>>     'ubelt/tests/util_cache',
+            >>>     'test-existing-versions').delete().ensuredir()
+            >>> cacher = ub.Cacher('versioned_data_v2', depends='1', dpath=dpath)
             >>> cacher.ensure(lambda: 'data1')
+            >>> known_fpaths = set()
             >>> known_fpaths.add(cacher.get_fpath())
-            >>> cacher = Cacher('versioned_data_v2', depends='2', dpath=dpath)
+            >>> cacher = ub.Cacher('versioned_data_v2', depends='2', dpath=dpath)
             >>> cacher.ensure(lambda: 'data2')
             >>> known_fpaths.add(cacher.get_fpath())
             >>> # List previously computed configs for this type
             >>> from os.path import basename
-            >>> cacher = Cacher('versioned_data_v2', depends='2', dpath=dpath)
+            >>> cacher = ub.Cacher('versioned_data_v2', depends='2', dpath=dpath)
             >>> exist_fpaths = set(cacher.existing_versions())
             >>> exist_fnames = list(map(basename, exist_fpaths))
             >>> print('exist_fnames = {!r}'.format(exist_fnames))
+            >>> print('exist_fpaths = {!r}'.format(exist_fpaths))
+            >>> print('known_fpaths={!r}'.format(known_fpaths))
             >>> assert exist_fpaths.issubset(known_fpaths)
         """
         import glob
@@ -482,7 +487,8 @@ class Cacher(object):
         Example:
             >>> from ubelt.util_cache import *  # NOQA
             >>> # Setting the cacher as enabled=False turns it off
-            >>> cacher = Cacher('test_disabled_load', '', enabled=True)
+            >>> cacher = Cacher('test_disabled_load', '', enabled=True,
+            >>>                 appname='ubelt/tests/util_cache')
             >>> cacher.save('data')
             >>> assert cacher.load() == 'data'
             >>> cacher.enabled = False
@@ -550,12 +556,14 @@ class Cacher(object):
             >>> from ubelt.util_cache import *  # NOQA
             >>> # Normal functioning
             >>> depends = 'long-cfg' * 32
-            >>> cacher = Cacher('test_enabled_save', depends=depends)
+            >>> cacher = Cacher('test_enabled_save', depends=depends,
+            >>>                 appname='ubelt/tests/util_cache')
             >>> cacher.save('data')
             >>> assert exists(cacher.get_fpath()), 'should be enabled'
             >>> assert exists(cacher.get_fpath() + '.meta'), 'missing metadata'
             >>> # Setting the cacher as enabled=False turns it off
-            >>> cacher2 = Cacher('test_disabled_save', 'params', enabled=False)
+            >>> cacher2 = Cacher('test_disabled_save', 'params', enabled=False,
+            >>>                  appname='ubelt/tests/util_cache')
             >>> cacher2.save('data')
             >>> assert not exists(cacher2.get_fpath()), 'should be disabled'
         """
