@@ -22,12 +22,12 @@ value of the ``bool(os.environ.get('NO_COLOR'))`` flag, which is compliant with
 [NoColor]_.
 
 
+Related work:
+    https://github.com/Textualize/rich
+
 References:
     .. [NoColor] https://no-color.org/
 
-Note:
-    In the future we may rename this module to ``util_ansi``.
-
 Requirements:
     pip install pygments
 """
@@ -122,16 +122,24 @@ def color_text(text, color):
         >>> import ubelt as ub
         >>> if ub.modname_to_modpath('pygments'):
         >>>     # Colors text only if pygments is installed
-        >>>     ansi_text = ub.ensure_unicode(color_text(text, 'red'))
+        >>>     ansi_text = ub.ensure_unicode(ub.color_text(text, 'red'))
         >>>     prefix = ub.ensure_unicode('\x1b[31')
         >>>     print('prefix = {!r}'.format(prefix))
         >>>     print('ansi_text = {!r}'.format(ansi_text))
         >>>     assert ansi_text.startswith(prefix)
-        >>>     assert color_text(text, None) == 'raw text'
+        >>>     assert ub.color_text(text, None) == 'raw text'
         >>> else:
         >>>     # Otherwise text passes through unchanged
-        >>>     assert color_text(text, 'red') == 'raw text'
-        >>>     assert color_text(text, None) == 'raw text'
+        >>>     assert ub.color_text(text, 'red') == 'raw text'
+        >>>     assert ub.color_text(text, None) == 'raw text'
+
+    Example:
+        >>> # xdoctest: +REQUIRES(module:pygments)
+        >>> import pygments.console
+        >>> import ubelt as ub
+        >>> known_colors = pygments.console.codes.keys()
+        >>> for color in known_colors:
+        ...     print(ub.color_text(color, color))
     """
     if NO_COLOR or color is None:
         return text
